import { TemplateModule } from "../types";
/**
 * Compiles Logimat to a math function (or multiple). Each function/variable will be on a separate line.
 * @param input {string} - is the input Logimat code that will be compiled.
 * @param useTex {boolean} - is a value indicating if the output should be converted to Tex.
 * @param noFS {boolean} - is a valid indicating if untrusted filesystem operations should be blocked (for example, code telling the compiler to load an NPM module). This is not a security feature.
 * @param filePath {string} - is a path to the file currently being compiled.
 * @param piecewise {boolean} - is a value indicating if the output should use piecewise instead of pure math for logic.
 * @param strict {boolean} - is a value indicating if an error should be thrown if an undefined function/variable is used.
 * @param noPolyfill {boolean} - should polyfills be disabled?
 * @param outputMaps {boolean} - is a value indicating if the output should be a map of simplified to unsimplified output.
 * @param simplificationMap {Record<string, string>} - is a map of simplified values to unsimplified values.
 * @param importMap {Record<string, TemplateModule>} - is a map of imports which will be used instead of require if specified.
 * @param unsafe {boolean} - is a value indicating if unsafe features (something where there can be ambiguity in how it is handled, such as with 0^0) are allowed. Enabling this generally makes compiled output smaller/faster.
 * @param unstable {boolean} - is a value indicating if unstable features (something which may not work in all cases but has todate, such as an unproven conjecture) are allowed. Enabling this generally makes compiled output smaller/faster.
 */
export declare const Compile: (input: string, useTex?: boolean, noFS?: boolean, filePath?: string, piecewise?: boolean, strict?: boolean, noPolyfill?: boolean, outputMaps?: boolean, simplificationMap?: Record<string, string>, importMap?: Record<string, TemplateModule | string>, unsafe?: boolean, unstable?: boolean) => Promise<string | {
    output: string[];
    simplificationMap: Record<string, string>;
    importMap: Record<string, TemplateModule | string>;
}>;
